@@ -23,10 +23,11 @@
 #include "plotitem.h"
 
 #include "analitza/analitzautils.h"
-#include <KLocalizedString>
 
 #include <QDebug>
-#include <KIcon>
+#include <QIcon>
+#include <QPixmap>
+#include <QCoreApplication>
 #include <analitzaplot/functiongraph.h>
 
 using namespace Analitza;
@@ -66,8 +67,8 @@ QVariant PlotsModel::headerData(int section, Qt::Orientation orientation, int ro
     if(role==Qt::DisplayRole && orientation==Qt::Horizontal) {
         switch(section) 
         {
-            case 0: return i18nc("@title:column", "Name");
-            case 1: return i18nc("@title:column", "Plot");
+			case 0: return QCoreApplication::translate("@title:column", "Name");
+			case 1: return QCoreApplication::translate("@title:column", "Plot");
         }
     }
     
@@ -203,14 +204,14 @@ void PlotsModel::addPlot(PlotItem* it)
     Q_ASSERT(it);
 
     beginInsertRows(QModelIndex(), m_items.count(), m_items.count());
-
     it->setModel(this);
     m_items.append(it);
-    
+
     if(FunctionGraph* g=dynamic_cast<FunctionGraph*>(it))
         g->setResolution(m_resolution);
-
     endInsertRows();
+
+    m_namingCount++;
 }
 
 void PlotsModel::updatePlot(int row, PlotItem* it)
@@ -243,8 +244,7 @@ QModelIndex PlotsModel::indexForName(const QString& name)
 
 QString PlotsModel::freeId() const
 {
-	//TODO: figure out a better way
-	return "f"+QString::number(qrand()*rowCount());
+	return "f"+QString::number(m_namingCount);
 }
 
 void PlotsModel::setResolution(int res)
